@@ -1,11 +1,9 @@
 import yaml
 from telegram import Update
-from telegram.ext import (CallbackContext, CallbackQueryHandler,
-                          CommandHandler, ConversationHandler, Filters,
-                          MessageHandler, PicklePersistence, PollAnswerHandler,
-                          PollHandler, TypeHandler, Updater)
+from telegram.ext import (CommandHandler, Filters, MessageHandler,
+                          PollAnswerHandler, TypeHandler)
 
-import digitalguide
+from digitalguide import rasa_filter, uhrzeit_filter
 from digitalguide.pattern import (EMOJI_PATTERN, JA_PATTERN, NEIN_PATTERN,
                                   WEITER_PATTERN, WOHIN_PATTERN)
 
@@ -52,9 +50,12 @@ def read_state_yml(filename, actions=None, prechecks: list = None):
                 elif handler["filter"] == "voice":
                     newHandler = MessageHandler(
                         Filters.voice, actions[handler["action"]])
+                elif handler["filter"] == "rasa":
+                    newHandler = MessageHandler(
+                        rasa_filter.FilterRasa(handler["intent"]), actions[handler["action"]])
                 elif handler["filter"] == "uhrzeit":
                     newHandler = MessageHandler(
-                        digitalguide.uhrzeit_filter.FilterUhrzeit(), actions[handler["action"]])
+                        uhrzeit_filter.FilterUhrzeit(), actions[handler["action"]])
                 else:
                     raise NotImplementedError(
                         "This filter is not implemented: {}".format(handler["filter"]))
