@@ -1,11 +1,18 @@
-from typing import List
-import yaml
-from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
+import json
+import os
 import re
+from configparser import ConfigParser
+from typing import List
 
-from digitalguide.pattern import EMOJI_PATTERN, WEITER_PATTERN, WOHIN_PATTERN, JA_PATTERN, NEIN_PATTERN
+import requests as req
+import yaml
+from digitalguide.pattern import (EMOJI_PATTERN, JA_PATTERN, NEIN_PATTERN,
+                                  WEITER_PATTERN, WOHIN_PATTERN)
+from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
+from requests.exceptions import Timeout
 
-def read_state_yml(filename, actions={}, prechecks:List=[]):
+
+def read_state_yml(filename, actions={}, prechecks: List = []):
     with open(filename) as file:
         yaml_dict = yaml.load(file, Loader=yaml.FullLoader)
 
@@ -15,7 +22,8 @@ def read_state_yml(filename, actions={}, prechecks:List=[]):
         handler_list = prechecks[:]
         for handler in handlers:
             if handler["handler"] == "PollAnswerHandler":
-                newHandler = MessageHandler(RegexFilter("^(.)+"), actions[handler["action"]])
+                newHandler = MessageHandler(RegexFilter(
+                    "^(.)+"), actions[handler["action"]])
             elif handler["handler"] == "MessageHandler":
                 if handler["filter"] == "regex":
                     if handler["regex"] == "EMOJI_PATTERN":
@@ -34,26 +42,35 @@ def read_state_yml(filename, actions={}, prechecks:List=[]):
                         newHandler = MessageHandler(RegexFilter(
                             NEIN_PATTERN), actions[handler["action"]])
                     else:
-                        newHandler = MessageHandler(RegexFilter(handler["regex"]), actions[handler["action"]])
+                        newHandler = MessageHandler(RegexFilter(
+                            handler["regex"]), actions[handler["action"]])
                 elif handler["filter"] == "text":
-                    newHandler = MessageHandler(TextFilter(), actions[handler["action"]])
+                    newHandler = MessageHandler(
+                        TextFilter(), actions[handler["action"]])
                 elif handler["filter"] == "photo":
-                    newHandler = MessageHandler(PhotoFilter(), actions[handler["action"]])
+                    newHandler = MessageHandler(
+                        PhotoFilter(), actions[handler["action"]])
                 elif handler["filter"] == "voice":
-                    newHandler = MessageHandler(VoiceFilter(), actions[handler["action"]])
+                    newHandler = MessageHandler(
+                        VoiceFilter(), actions[handler["action"]])
+                elif handler["filter"] == "rasa":
+                    newHandler = MessageHandler(FilterRasa(
+                        handler["intent"]), actions[handler["action"]])
             elif handler["handler"] == "CommandHandler":
-                newHandler = CommandHandler(handler["command"], actions[handler["action"]])
+                newHandler = CommandHandler(
+                    handler["command"], actions[handler["action"]])
             elif handler["handler"] == "TypeHandler":
                 if handler["type"] == "Update":
                     type_ = WhatsAppUpdate
                 newHandler = TypeHandler(type_, actions[handler["action"]])
-                
+
             handler_list.append(newHandler)
 
-        states_dict[state]= handler_list
+        states_dict[state] = handler_list
 
     return states_dict
 
+
 class MessageHandler:
     def __init__(self, filters, callback):
         self.filters = filters
@@ -62,6 +79,7 @@ class MessageHandler:
     def check_update(self, update: WhatsAppUpdate):
         return self.filters(update)
 
+
 class CommandHandler:
     def __init__(self, command, callback):
         self.command = command
@@ -71,6 +89,7 @@ class CommandHandler:
         if update.Body.strip("/").lower() == self.command.lower():
             return True
 
+
 class TypeHandler:
     def __init__(self, type_, callback):
         self.type_ = type_
@@ -79,6 +98,7 @@ class TypeHandler:
     def check_update(self, update: WhatsAppUpdate):
         return type(update) is self.type_
 
+
 class RegexFilter:
     def __init__(self, regex) -> None:
         self.regex = regex
@@ -86,14 +106,50 @@ class RegexFilter:
     def __call__(self, update: WhatsAppUpdate) -> bool:
         return re.match(self.regex, update.Body)
 
+
 class TextFilter:
     def __call__(self, update: WhatsAppUpdate) -> bool:
         return update.Body != ""
 
+
 class PhotoFilter:
     def __call__(self, update: WhatsAppUpdate) -> bool:
         return update.MediaContentType0 and update.MediaContentType0.startswith("image")
 
+
 class VoiceFilter:
     def __call__(self, update: WhatsAppUpdate) -> bool:
-        return update.MediaContentType0 and update.MediaContentType0.startswith("audio")
\ No newline at end of file
+        return update.MediaContentType0 and update.MediaContentType0.startswith("audio")
+
+
+config = ConfigParser()
+config.read('config.ini')
+
+
+class FilterRasa:
+    def __init__(self, intent, confidence=0.8):
+        self.intent = intent
+        self.confidence = confidence
+
+    def __call__(self, update: WhatsAppUpdate):
+        try:
+            payload = json.dumps({
+                "username": os.getenv('RASA_USER'),
+                "password": os.getenv('RASA_PASSWORD')
+            })
+
+            token_response = req.post(
+                config["rasa"]["url"] + "/api/auth", data=payload)
+            print(token_response.json())
+
+            RASA_TOKEN = token_response.json()["access_token"]
+            response = req.post(config["rasa"]["url"] + "/api/projects/default/logs", params={
+                                "q": update.Body}, headers={'Authorization': 'Bearer {}'.format(RASA_TOKEN)},  timeout=(3, 8))
+            print(response.json())
+        except (Timeout, KeyError) as e:
+            print(e)
+            False
+        else:
+            if not response.ok:
+                return False
+            return response.json()["user_input"]["intent"]["name"] == self.intent and response.json()["user_input"]["intent"]["confidence"] >= self.confidence
